<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;

class RelLogControleDeAcessoController extends CrudWithParameterBag {
    protected $dataSourceName = 'vnd62000_relLogControleDeAcesso'; 
    protected $parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDCAIXA', 'TCDCAIXA', 'IDOPERFOS', 'TIDOPERFOS', 'DATAINI', 'DATAFIN', 'CDOPERADOR');
   
    public function __construct($dataSourceManager, $parameterBag, $utilService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        
        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->buildParams($conditions);
        
        if(isset($conditions['DATAINI']) && !empty($conditions['DATAINI']) && 
           isset($conditions['DATAFIN']) && !empty($conditions['DATAFIN'])) {
            foreach($conditions as $key => $value) {
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator" => "=",
                    "value" => $value
                );
            }
            
            // para o CTRL+F funcionar
            for($i = 0; $i < count($conditions); $i++) {
                if(strpos($dataSourceFilter[$i]["columnName"], '|') != false) {
                    $dataSourceFilter[$i]["operator"] = "MAPPED_LIKE_ALL";
                }
            }
            
            $newRequest = new DTO\Request\Filter (
                new FilterCriteria(
                    $request->getFilterCriteria()->getDataSourceName(),
                    $dataSourceFilter,
                    $request->getFilterCriteria()->getPage(),
                    $request->getFilterCriteria()->getPageSize()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            
            $result = parent::find($newRequest, $response);
        }
        
        return $result;
    }
    
    public function buildParams($conditions) {
        if(!isset($conditions['CDFILIAL'])) {
            $conditions['CDFILIAL'] = '';
        } else {
            $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
            $conditions['CDOPERADOR'] = '';
        }
        
        if(!isset($conditions['CDCAIXA'])) {
            $conditions['CDCAIXA'] = '';
            $conditions['TCDCAIXA'] = 'T';
        } else {
            $conditions['CDCAIXA'] = implode('_', $conditions['CDCAIXA']);
            $conditions['TCDCAIXA'] = '';
        }
        
        if(!isset($conditions['IDOPERFOS'])) {
            $conditions['IDOPERFOS'] = '';
            $conditions['TIDOPERFOS'] = 'T';
        } else {
            $conditions['IDOPERFOS'] = implode('_', $conditions['IDOPERFOS']);
            $conditions['TIDOPERFOS'] = '';
        }
        
        if(isset($conditions['DTDIA'])) {
            $conditions['DATAINI'] = $conditions['DTDIA'][0];
            $conditions['DATAFIN'] = $conditions['DTDIA'][1];
            unset($conditions['DTDIA']);
        }
        
        return $conditions;
    }
}